@@ -3,9 +3,9 @@ use strict;
 use warnings;
 
 use LWP::UserAgent;
-use HTML::TreeBuilder::XPath;
+use JSON;
 
-our $VERSION = 1.031;
+our $VERSION = 1.04;
 
 use Encode;
 use utf8;
@@ -22,11 +22,11 @@ sub new {
 
         _post_url => defined $params->{post_url}
         ? $params->{post_url}
-        : 'http://www.buscacep.correios.com.br/sistemas/buscacep/resultadoBuscaCepEndereco.cfm',
+        : 'https://buscacep.correios.com.br/app/endereco/carrega-cep-endereco.php',
 
         _post_content => defined $params->{post_content}
         ? $params->{post_content}
-        : 'tipoCEP=LOG&semelhante=N&relaxation='
+        : '?pagina=%2Fapp%2Fendereco%2Findex.php&cepaux=&mensagem_alerta=&tipoCEP=LOG&endereco='
     };
 
     $this->{_lwp_options}{timeout} = $params->{timeout}
@@ -65,9 +65,9 @@ sub _extractAddress {
         }
         my $ua = $this->{_lwp_ua};
 
-        my $req = HTTP::Request->new( POST => $this->{_post_url} );
-        $req->content_type('application/x-www-form-urlencoded');
-        $req->content( $this->{_post_content} . $cep );
+        my $url = $this->{_post_url} . $this->{_post_content} . $cep;
+        my $req = HTTP::Request->new( GET => $url );
+
         eval {
             local $SIG{ALRM} =
               sub { die "Can't connect to server [alarm timeout]\n" };
@@ -77,8 +77,9 @@ sub _extractAddress {
             my $res = $ua->request($req);
 
             # Check the outcome of the response
+
             if ( $res->is_success ) {
-                $this->_parseHTML( \@result, $res->content, $as_html_tree );
+                $this->_parseJSON( \@result, $res->content, $as_html_tree );
             }
             else {
                 $result[0]->{status} = "Error: " . $res->status_line;
@@ -91,18 +92,12 @@ sub _extractAddress {
     return wantarray ? @result : $result[0];
 }
 
-sub _parseHTML {
-    my ( $this, $address_ref, $html, $as_html_tree ) = @_;
+sub _parseJSON {
+    my ( $this, $address_ref, $json, $as_html_tree ) = @_;
 
-    my $tree = HTML::TreeBuilder::XPath->new;
-    $html = decode( 'iso-8859-1', $html );
-    $html =~ s/&nbsp;//g;    # <-- findvalue is keeping that
-    $tree->parse_content($html);
+    my $obj = from_json($json);
 
-    my $ref =
-      $tree->findnodes('//table[contains(@class,"tmptabela")]/tr[not(th)]');
-
-    while ( my $p = shift(@$ref) ) {
+    for my $p ( @{ $obj->{dados} || [] } ) {
 
         if ($as_html_tree) {
             push( @$address_ref, $p );
@@ -110,20 +105,17 @@ sub _parseHTML {
         else {
             my $address = {};
 
-            $address->{street}       = $p->findvalue('./td[1]');
-            $address->{neighborhood} = $p->findvalue('./td[2]');
-            $address->{cep}          = $p->findvalue('./td[4]');
+            $address->{street}       = $p->{logradouroDNEC};
+            $address->{neighborhood} = $p->{bairro};
+            $address->{cep} =
+              substr( $p->{cep}, 0, 5 ) . '-' . substr( $p->{cep}, 5, 3 );
 
-            ( $address->{location}, $address->{uf} ) =
-              split qr{\s*/\s*} => $p->findvalue('./td[3]');
+            $address->{location} = $p->{localidade};
+            $address->{uf}       = $p->{uf};
 
-            if ( $address->{cep} ) {
-                $address->{status} = '';
-            }
-            else {
-                $address->{status} =
-                  'Error: Address not found, something is wrong...';
-            }
+            $address->{status} = $p->{situacao};
+
+            $address->{raw} = $p;
 
             push( @$address_ref, $address );
         }
@@ -196,7 +188,7 @@ Extra options to pass to LWP::UserAgent.
 
 =back
 
-=head2 find( $cep [, $as_html_tree ] )
+=head2 find( $cep [, $all_result_raw ] )
 
 Recieves the CEP string and tries to get address data. Returns a hashref with the following keys:
 
@@ -218,7 +210,7 @@ If there is more than one address, it returns a list of hashrefs in list context
 just the first hashref in scalar context, together with an "C<address_count>" key with
 the total returned addresses.
 
-If $as_html_tree is passed, return a list of Tree::XPathEngine::NodeSet (from HTML::TreeBuilder::XPath->findnodes())
+If $all_result_raw is passed, return a list of all results from correios
 
 =head1 SEE ALSO
 
@@ -255,6 +247,8 @@ solution for finding addresses!
 
 2014 - Thanks to Garu, for removing legacy test code and improving docs!
 
+2020- Nov 14, Correios now have a json result, and now this module is here just for retrocompatibility, html parsing is not required anymore.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2011-2014 by RenatoCRON
